from django.apps import AppConfig


class TinymceFilebrowserConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'tinymce_filebrowser'
